@@ -92,19 +92,24 @@ def dpkg_detect(pkgs, exec_fn=None):
             ret_list.append( pkg_row[0])
     return [version_lock_map[r] for r in ret_list]
 
+
 class AptInstaller(PackageManagerInstaller):
-    """ 
+    """
     An implementation of the Installer for use on debian style
     systems.
     """
     def __init__(self):
         super(AptInstaller, self).__init__(dpkg_detect)
 
-    def get_install_command(self, resolved, interactive=True, reinstall=False):
+    def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         packages = self.get_packages_to_install(resolved, reinstall=reinstall)
         if not packages:
             return []
+        if not interactive and quiet:
+            return [self.elevate_priv(['apt-get', 'install', '-y', '-qq', p]) for p in packages]
+        elif quiet:
+            return [self.elevate_priv(['apt-get', 'install', '-qq', p]) for p in packages]
         if not interactive:
-            return [['sudo', 'apt-get', 'install', '-y', p] for p in packages]
+            return [self.elevate_priv(['apt-get', 'install', '-y', p]) for p in packages]
         else:
-            return [['sudo', 'apt-get', 'install', p] for p in packages]
+            return [self.elevate_priv(['apt-get', 'install', p]) for p in packages]
