@@ -30,6 +30,8 @@
 
 import subprocess
 import json
+import sys
+import traceback
 
 from rospkg.os_detect import OS_OSX
 
@@ -99,7 +101,7 @@ class MacportsInstaller(PackageManagerInstaller):
             return []
         else:
             #TODO: interactive
-            return [['sudo', 'port', 'install', p] for p in packages]
+            return [self.elevate_priv(['port', 'install', p]) for p in packages]
 
 def is_brew_installed():
     try:
@@ -188,10 +190,14 @@ def brew_detect(resolved, exec_fn=None):
                 if spec['version'] == linked_version:
                     installed_options = spec['used_options']
                     break
-        except (ValueError, TypeError) as e:
+        except (ValueError, TypeError):
+            e_type, e, tb = sys.exc_info()
             raise RosdepInternalError(
-                "Error while parsing brew package info for '%s'\n-info: '%s'\n-error: '%s'." %
-                (r.package, std_out, e))
+                e, """Error while parsing brew info for '{0}'
+ * Output of `brew info {0} --json=v1`:
+ {1}
+ * Error while parsing:
+ {2}""".format(r.package, std_out, "".join(traceback.format_exception(e_type, e, tb))))
 
         if set(r.options) <= set(installed_options):
             return True
@@ -243,6 +249,7 @@ class HomebrewInstaller(PackageManagerInstaller):
 
     def __init__(self):
         super(HomebrewInstaller, self).__init__(brew_detect, supports_depends=True)
+        self.as_root = False
 
     def resolve(self, rosdep_args):
         """
@@ -297,7 +304,7 @@ class HomebrewInstaller(PackageManagerInstaller):
             resolution = map(HomebrewResolution, packages, install_flags, options)
         return resolution
 
-    def get_install_command(self, resolved, interactive=True, reinstall=False):
+    def get_install_command(self, resolved, interactive=True, reinstall=False, quiet=False):
         # TODO: We should somehow inform the user that we uninstall all versions
         #       of packages and do not keep track of which options have been
         #       activated. Then again, maybe not this would be the
@@ -312,11 +319,11 @@ class HomebrewInstaller(PackageManagerInstaller):
             commands = []
             for r in resolved:
                 # --force uninstalls all versions of that package
-                commands.append(['brew', 'uninstall', '--force', r.package])
-                commands.append(['brew', 'install'] + r.to_list())
+                commands.append(self.elevate_priv(['brew', 'uninstall', '--force', r.package]))
+                commands.append(self.elevate_priv(['brew', 'install'] + r.to_list()))
             return commands
         else:
-            return [['brew', 'install'] + r.to_list() for r in resolved]
+            return [self.elevate_priv(['brew', 'install'] + r.to_list()) for r in resolved]
 
     def remove_duplicate_dependencies(self, resolved):
         # TODO: we do not look at options here, however the install check later
