@@ -47,6 +47,35 @@ def test_rpm_detect():
     val = rpm_detect(['tinyxml-dev'], exec_fn=m)
     assert val == [], val
 
+def test_DnfInstaller():
+    from rosdep2.platforms.redhat import DnfInstaller
+
+    @patch.object(DnfInstaller, 'get_packages_to_install')
+    def test(mock_method):
+        installer = DnfInstaller()
+        mock_method.return_value = []
+        assert [] == installer.get_install_command(['fake'])
+
+        # no interactive option with YUM
+        mock_method.return_value = ['a', 'b']
+        expected = [['sudo', 'dnf', '--assumeyes', '--quiet', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=False, quiet=True)
+        assert val == expected, val + expected
+        expected = [['sudo', 'dnf', '--quiet', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=True, quiet=True)
+        assert val == expected, val + expected
+        expected = [['sudo', 'dnf', '--assumeyes', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=False, quiet=False)
+        assert val == expected, val + expected
+        expected = [['sudo', 'dnf', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=True, quiet=False)
+        assert val == expected, val + expected
+    try:
+        test()
+    except AssertionError:
+        traceback.print_exc()
+        raise
+
 def test_YumInstaller():
     from rosdep2.platforms.redhat import YumInstaller
 
@@ -58,11 +87,17 @@ def test_YumInstaller():
 
         # no interactive option with YUM
         mock_method.return_value = ['a', 'b']
-        expected = [['sudo', 'yum', '-y', '--skip-broken', 'install', 'a', 'b']]
-        val = installer.get_install_command(['whatever'], interactive=False)
+        expected = [['sudo', 'yum', '--assumeyes', '--quiet', '--skip-broken', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=False, quiet=True)
+        assert val == expected, val + expected
+        expected = [['sudo', 'yum', '--quiet', '--skip-broken', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=True, quiet=True)
+        assert val == expected, val + expected
+        expected = [['sudo', 'yum', '--assumeyes', '--skip-broken', 'install', 'a', 'b']]
+        val = installer.get_install_command(['whatever'], interactive=False, quiet=False)
         assert val == expected, val + expected
         expected = [['sudo', 'yum', '--skip-broken', 'install', 'a', 'b']]
-        val = installer.get_install_command(['whatever'], interactive=True)
+        val = installer.get_install_command(['whatever'], interactive=True, quiet=False)
         assert val == expected, val + expected
     try:
         test()
